@@ -25,7 +25,7 @@ class OpenPackagingConvention(FileInterface):
     _global_metadata_file = "/Metadata/OPC_Global.json"  # Where the global metadata file is.
     _opc_metadata_relationship_type = "http://schemas.ultimaker.org/package/2018/relationships/opc_metadata"  # Unique identifier of the relationship type that relates OPC metadata to files.
     _metadata_prefix = "/metadata"
-    _aliases = OrderedDict([])  # A standard OPC file doest not have default aliases. These must be implemented in inherited classes.
+    _aliases = OrderedDict([])  # type: Dict[str, str]  # A standard OPC file doest not have default aliases. These must be implemented in inherited classes.
 
     mime_type = "application/x-opc"
 
@@ -298,7 +298,11 @@ class OpenPackagingConvention(FileInterface):
 
         # Replace all aliases.
         for regex, replacement in self._aliases.items():
-            virtual_path = re.sub(regex, replacement, virtual_path)
+            if regex.startswith("/"):
+                expression = r"^" + regex
+            else:
+                expression = regex
+            virtual_path = re.sub(expression, replacement, virtual_path)
 
         return virtual_path
 
