@@ -8,7 +8,7 @@ if [ -n "${MYPY_FILES}" ] ; then
     echo "Testing ${MYPY_FILES}"
     for file in ${MYPY_FILES} ; do
         echo "Mypying ${file}"
-        mypy --config-file=mypy.ini --cache-dir=/dev/null "${file}"
+        mypy --config-file=mypy.ini --follow-imports=skip --cache-dir=/dev/null "${file}"
     done
 fi
 
